@@ -372,7 +372,7 @@ public class GathererThread extends Thread {
 		if (this.channel.get(this.recordSetKey1) != null) {
 			this.channel.get(this.recordSetKey1).clear();
 			this.channel.remove(this.recordSetKey1);
-			if (Thread.currentThread().getId() == this.application.getThreadId()) {
+			if (Thread.currentThread().threadId() == this.application.getThreadId()) {
 				this.application.getMenuToolBar().updateRecordSetSelectCombo();
 				this.application.updateStatisticsData();
 				this.application.updateDataTable(this.recordSetKey1, true);
