@@ -45,6 +45,7 @@ import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.Point;
+import org.eclipse.swt.graphics.RGB;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
@@ -62,6 +63,7 @@ import gde.log.LogFormatter;
 import gde.messages.MessageIds;
 import gde.messages.Messages;
 import gde.ui.DataExplorer;
+import gde.ui.SWTResourceManager;
 import gde.utils.FileUtils;
 import gde.utils.StringHelper;
 
@@ -85,7 +87,7 @@ public class GDE {
 		}
 
 		public void setProgress(int percentage) {
-			String sThreadId = String.format("%06d", Thread.currentThread().getId()); //release >= 19 -> threadId()
+			String sThreadId = String.format("%06d", Thread.currentThread().threadId()); //release >= 19 -> threadId()
 			application.setProgress(percentage, sThreadId);
 		}
 
@@ -106,10 +108,10 @@ public class GDE {
 	private static boolean									isWithUi													= false;
 
 	// ****** begin global constants section *******
-	public static final String							VERSION														= "Version 3.9.9"; // check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
+	public static final String							VERSION														= "Version 4.0.0"; // do not use more than 3 digits, check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
 	public static final int									VERSION_NUMBER										= GDE.VERSION.contains("beta") 
-															? Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY)) - 1
-															: Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY));
+															? Integer.parseInt(GDE.VERSION.substring(8, GDE.VERSION.indexOf("beta")-1).replace(GDE.STRING_DOT, GDE.STRING_EMPTY).trim()) - 1
+															: Integer.parseInt(GDE.VERSION.substring(8, GDE.VERSION.length()).replace(GDE.STRING_DOT, GDE.STRING_EMPTY).trim());
 	public static final String							NAME_SHORT												= "GDE";																																																										//$NON-NLS-1$
 	public static final String							NAME_LONG													= "DataExplorer";																																																						//$NON-NLS-1$
 	public final static String							DEVICE_PROPERTIES_XSD_VERSION			= "_V50";																																																										//$NON-NLS-1$
@@ -542,15 +544,8 @@ public class GDE {
 			int javaVmSpecificationVersion = Integer.parseInt(((String)props.get("java.vm.specification.version")).contains(GDE.STRING_DOT) 
 					? ((String)props.get("java.vm.specification.version")).substring(2) : ((String)props.get("java.vm.specification.version")));
 			
-			if (IS_ARCH_DATA_MODEL_64 || IS_OS_ARCH_ARM) {
-				if (javaVmSpecificationVersion < 17 || javaVmSpecificationVersion > 21) {
-					application.openMessageDialogAsync(Messages.getString(MessageIds.GDE_MSGW0050, new Integer[] { javaVmSpecificationVersion }));
-				}
-			}
-			else {
-				if (javaVmSpecificationVersion < 8 || javaVmSpecificationVersion > 21) {
-					application.openMessageDialogAsync(Messages.getString(MessageIds.GDE_MSGW0050, new Integer[] { javaVmSpecificationVersion }));
-				}
+			if (javaVmSpecificationVersion < 19 || javaVmSpecificationVersion > 25) {
+				application.openMessageDialogAsync(Messages.getString(MessageIds.GDE_MSGW0050, new Integer[] { javaVmSpecificationVersion }));
 			}
 			application.execute(inputFilePath);
 		}
@@ -791,8 +786,11 @@ public class GDE {
 	 * @return if dark theme is configured, ARM 32 swt.jar is to old and does not know dark theme 
 	 */
 	public static boolean isSystemDarkTheme() {
-		if (GDE.IS_OS_ARCH_ARM || GDE.IS_WINDOWS)
-			return false;
+		if (GDE.IS_LINUX) {
+			RGB backgroundRGB = SWTResourceManager.getColor(SWT.COLOR_WIDGET_BACKGROUND).getRGB();
+			int rgbSum = backgroundRGB.red + backgroundRGB.green + backgroundRGB.blue;
+			return rgbSum < 250;
+		}		
 		return Display.isSystemDarkTheme();
 	}
 }
