@@ -33,6 +33,7 @@ import java.util.stream.Collectors;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CTabItem;
 import org.eclipse.swt.custom.SashForm;
+import org.eclipse.swt.custom.StyledText;
 import org.eclipse.swt.events.HelpEvent;
 import org.eclipse.swt.events.HelpListener;
 import org.eclipse.swt.events.MouseAdapter;
@@ -43,10 +44,12 @@ import org.eclipse.swt.events.PaintEvent;
 import org.eclipse.swt.events.PaintListener;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
+import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.widgets.Canvas;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Listener;
 import org.eclipse.swt.widgets.Menu;
+import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import gde.GDE;
@@ -58,6 +61,7 @@ import gde.histo.datasources.SourceFolders;
 import gde.histo.recordings.TrailDataTags.DataTag;
 import gde.histo.recordings.TrailRecord;
 import gde.histo.recordings.TrailRecordSet;
+import gde.histo.recordings.TrailRecordSetFormatter;
 import gde.histo.ui.menu.AbstractTabAreaContextMenu.TabMenuOnDemand;
 import gde.histo.ui.menu.ChartTabAreaContextMenu;
 import gde.histo.utils.HistoCurveUtils;
@@ -220,6 +224,12 @@ public final class GraphicsComposite extends AbstractChartComposite {
 	private final HistoTimeLine			timeLine	= new HistoTimeLine();
 
 	private final AbstractChartData	chartData	= new AbstractChartData();
+	
+	final 	Rectangle 							monitorBounds 					= GDE.display.getPrimaryMonitor().getBounds();
+	private Shell 									measurePopUp;
+	private StyledText							styledText;
+	int															lastXPositionMeasure		= Integer.MAX_VALUE;
+
 
 	GraphicsComposite(SashForm useParent, CTabItem parentWindow) {
 		super(useParent, parentWindow, SWT.NONE);
@@ -656,5 +666,59 @@ public final class GraphicsComposite extends AbstractChartComposite {
 	public GraphicsLayout getChartData(TrailRecord trailRecord) {
 		return (GraphicsLayout) this.chartData.get(trailRecord.getName());
 	}
+	
+	public void callMeasurePopUp(long timestamp_ms) {
+		boolean isCreated = false;
+		if (measurePopUp == null || (measurePopUp != null && measurePopUp.isDisposed())) {
+			measurePopUp = new Shell(GDE.shell, SWT.NO_TRIM | SWT.MODELESS);
+			measurePopUp.setParent(this);
+			measurePopUp.setLayout(new FillLayout());
+			measurePopUp.setAlpha(200);
+			isCreated = true;
+		}
+		if (styledText == null || (styledText != null && styledText.isDisposed())) {
+			styledText = new StyledText(measurePopUp, SWT.NONE);
+			styledText.setEditable(false);
+			styledText.setEnabled(false);
+			styledText.setFont(SWTResourceManager.getFont("Courier New", GDE.WIDGET_FONT_SIZE + 1, SWT.BOLD));
+		}
+
+		if (GraphicsMeasuring.xPosMeasure != lastXPositionMeasure) {
+			TrailRecordSetFormatter.setSelectedMeasurementsAsTable4PopUp(styledText, timestamp_ms);
+			
+			measurePopUp.pack();
+			
+			int locationX = GDE.shell.getLocation().x + (GDE.shell.getBounds().width - this.getBounds().width) + this.timeLine.getCurveAreaBounds().x + GraphicsMeasuring.xPosMeasure + 20;
+			locationX = (locationX + measurePopUp.getBounds().width) > monitorBounds.width || GraphicsMeasuring.xPosMeasure > lastXPositionMeasure && locationX - 30 - measurePopUp.getBounds().width > 0
+					? locationX - 30 - measurePopUp.getBounds().width : locationX;
+	
+			int locationY = GDE.shell.getLocation().y + this.application.getTabFolder().getLocation().y + this.graphicsHeader.getBounds().height + GraphicsMeasuring.yPosMeasure + 18;
+			locationY = locationY < 0 ? GDE.shell.getLocation().y + this.application.getTabFolder().getLocation().y + this.graphicsHeader.getBounds().height + this.graphicCanvas.getBounds().height/2 : locationY;
+	
+			measurePopUp.setLocation(locationX, locationY);
+			
+			if (isCreated) {
+				measurePopUp.getDisplay().asyncExec(new Runnable() {
+					public void run() {
+						measurePopUp.open();
+					}
+				});
+			}
+			lastXPositionMeasure = GraphicsMeasuring.xPosMeasure;
+		}
+
+	}
+	
+	public void cleanMeasurePopUp() {
+		if (measurePopUp != null && !measurePopUp.isDisposed()) {
+			//log.log(Level.OFF, "cleanMeasurePopUp");
+			if (styledText != null && !styledText.isDisposed()) {
+				styledText.dispose();
+				styledText = null;
+			}
+			measurePopUp.close();
+			measurePopUp = null;
+		}
+	}
 
 }
