@@ -94,7 +94,7 @@ public final class HistoGraphicsWindow extends AbstractChartWindow {
 	public void redrawGraphics(final boolean redrawCurveSelector) {
 		if (windowActor.getTrailRecordSet() == null) return ;
 
-		if (Thread.currentThread().getId() == DataExplorer.getInstance().getThreadId()) {
+		if (Thread.currentThread().threadId() == DataExplorer.getInstance().getThreadId()) {
 			if (redrawCurveSelector) this.curveSelectorComposite.doUpdateCurveSelectorTable();
 
 			this.graphicsComposite.doRedrawGraphics();
@@ -118,7 +118,7 @@ public final class HistoGraphicsWindow extends AbstractChartWindow {
 	@Override
 	@Deprecated
 	public void updateCaptions() {
-		if (Thread.currentThread().getId() == DataExplorer.getInstance().getThreadId()) {
+		if (Thread.currentThread().threadId() == DataExplorer.getInstance().getThreadId()) {
 			this.graphicsComposite.updateCaptions();
 		} else {
 			GDE.display.asyncExec(new Runnable() {
@@ -176,7 +176,7 @@ public final class HistoGraphicsWindow extends AbstractChartWindow {
 	@Override
 	public void setCurveAreaBackground(Color curveAreaBackground) {
 		this.graphicsComposite.curveAreaBackground = curveAreaBackground;
-		this.graphicsComposite.graphicCanvas.redraw();
+		this.graphicsComposite.doRedrawGraphics();
 	}
 
 	@Override
@@ -185,6 +185,20 @@ public final class HistoGraphicsWindow extends AbstractChartWindow {
 		this.graphicsComposite.graphicCanvas.redraw();
 	}
 
+	@Override
+	public void setHeaderCommentColor(Color headerCommentColor) {
+		this.graphicsComposite.headerCommentColor = headerCommentColor;
+		this.graphicsComposite.graphicsHeader.setForeground(headerCommentColor);
+		this.graphicsComposite.graphicsHeader.redraw();
+		this.graphicsComposite.recordSetComment.setForeground(headerCommentColor);
+		this.graphicsComposite.recordSetComment.redraw();
+	}
+
+	@Override
+	public void setTimeLineColor(Color timeLineColor) {
+		this.graphicsComposite.graphicCanvas.redraw();
+	}
+
 	@Override
 	public void setSurroundingBackground(Color surroundingBackground) {
 		this.graphicsComposite.surroundingBackground = surroundingBackground;
