@@ -46,7 +46,6 @@ import gde.histo.recordings.TrailRecordSet;
 import gde.log.Logger;
 import gde.messages.MessageIds;
 import gde.messages.Messages;
-import gde.ui.DataExplorer;
 import gde.utils.GraphicsUtils;
 import gde.utils.LocalizedDateTime;
 import gde.utils.LocalizedDateTime.DateTimePattern;
@@ -364,7 +363,7 @@ public final class HistoTimeLine {
 	public void drawTimeLine(GC gc) {
 		gc.setLineWidth(1);
 		gc.setLineStyle(SWT.LINE_SOLID);
-		gc.setForeground(DataExplorer.getInstance().COLOR_BLACK);
+		gc.setForeground(Settings.getInstance().getTimeLineColor());
 
 		int x0 = curveAreaBounds.x;
 		int y0 = curveAreaBounds.y + curveAreaBounds.height;
