@@ -24,7 +24,6 @@ import gde.data.Channel;
 import gde.data.Channels;
 import gde.data.RecordSet;
 import gde.device.ChannelTypes;
-import gde.device.skyrc.MC3000.SlotSettings;
 import gde.device.skyrc.MC3000UsbPort.QuerySlotData;
 import gde.exception.ApplicationConfigurationException;
 import gde.exception.DataInconsitsentException;
@@ -39,7 +38,6 @@ import java.util.logging.Logger;
 
 import javax.usb.UsbDisconnectedException;
 import javax.usb.UsbException;
-import javax.usb.UsbInterface;
 import javax.usb.UsbNotClaimedException;
 
 /**
@@ -589,7 +587,7 @@ public class MC3000GathererThread extends Thread {
 		if (this.channel.get(this.recordSetKey) != null) {
 			this.channel.get(this.recordSetKey).clear();
 			this.channel.remove(this.recordSetKey);
-			if (Thread.currentThread().getId() == this.application.getThreadId()) {
+			if (Thread.currentThread().threadId() == this.application.getThreadId()) {
 				this.application.getMenuToolBar().updateRecordSetSelectCombo();
 				this.application.updateStatisticsData();
 				this.application.updateDataTable(this.recordSetKey, true);
