@@ -298,7 +298,7 @@ public class SpektrumAdapter extends DeviceConfiguration implements IDevice {
 	public void addDataBufferAsRawDataPoints(RecordSet recordSet, byte[] dataBuffer, int recordDataSize, boolean doUpdateProgressBar) throws DataInconsitsentException {
 		int dataBufferSize = GDE.SIZE_BYTES_INTEGER * recordSet.getNoneCalculationRecordNames().length;
 		int[] points = new int[recordSet.getNoneCalculationRecordNames().length];
-					String sThreadId = String.format("%06d", Thread.currentThread().getId()); //$NON-NLS-1$
+					String sThreadId = String.format("%06d", Thread.currentThread().threadId()); //$NON-NLS-1$
 		int progressCycle = 1;
 		if (doUpdateProgressBar) SpektrumAdapter.application.setProgress(progressCycle, sThreadId);
 
